==> snf_3.3.0_webrelease.tar.gz: snf_3.3.0_webrelease/src/snfdc/daltonrslave.r <==
CC******************************************************************************
C   Copyright 1999 -- 2002 C. Kind, M. Reiher, J. Neugebauer, and B. A. Hess,
C   Chair of Theoretical Chemistry, Friedrich-Alexander-University 
C   Erlangen-Nuremberg, Egerlandstr. 3, D-91058 Erlangen, Germany.
C
C
C   This file is part of the package SNF.
C
C   SNF is free software; you can redistribute it and/or modify
C   it under the terms of the GNU General Public License as published by
C   the Free Software Foundation; either version 2 of the License, or
C   (at your option) any later version.
C
C   This program is distributed in the hope that it will be useful,
C   but WITHOUT ANY WARRANTY; without even the implied warranty of
C   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C   GNU General Public License for more details.
C
C   You should have received a copy of the GNU General Public License
C   along with this program; if not, write to the Free Software
C   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
C
CC******************************************************************************
      subroutine daltonrslave(grad,co,ilab,nmode,freq,intonly,nummodes)
C>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
C written by J. Neugebauer, Uni Erlangen, 2003
C extended by M. Reiher, Uni Erlangen, June 2003
C modified by M. Reiher, Uni Bonn, April 2004
C modified by C. Herrmann, 02/2005
C>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
      include 'defs.h'
      include 'comm.h'
      include 'param.h'  

      integer ibuf,info,nn,iat,idum,ixyz,irc,idir,l,mypid
      integer idmy,j,mbuf,diraus,ldal,iclean,icleanl
      character*255 dalname
      real*8 escf,gsum
      real*8 nmode(maxmode,maxatoms*3),freq(maxmode)

      integer lprop,lpol,ldscf,lgrad,kstep,xprog,ldmol
      integer xprogb
      integer*4 itst,jstepa
      character*255 b1
      character*5 nic
      character*80 sdum,dalmw
      character*24 date,dmname
      character*255 dscfname,gradname,propname,polname
      real*8 cpu,wall,gcpu,gwall
      integer nit
      integer xeq,tmpxeq,icmp,idalmw,ldalmw
      real*8 grad(nvar),dipol(3),co(3,natoms),polar(8,mxomeg)
      real*8 gtenlao(9,mxomeg),gtenao(9,mxomeg),aten(27,mxomeg)
      real*8 dipal(3),dipbe(3)
      integer ilab(natoms)

      logical found,snffast
C#    integer w,st(MPI_STATUS_SIZE)
C#    data w /MPI_COMM_WORLD/
 
      logical vroaflag
      integer ipoldum

      integer intonly,nummodes

      vroaflag=.false.
      ipoldum=ipol
      if ((ipol-1000).ge.0) then
        vroaflag=.true.
        ipoldum=ipol-1000
        if (ipoldum.eq.0) ipoldum=1
      end if

      nic='nice '
      kstep=1
      idalmw=0
      call clean(dalmw)

*-------------------
* call rslave module
*-------------------
      call rslave(co,ilab,jstepa,nmode,freq,intonly,nummodes)

*-------------------
* do the calculation
*-------------------
      if(snffast) then
        nic='     '
        write (iosl,*) '** found $snffast flag: omitting command nice'
      end if
      call flush(iosl)
      if(snffast) then
        nic='     '
        write (iosl,*) 'test calculation: omitting command nice'
      end if

*--------------------------
* prepare output file names
*--------------------------
      call augnum(dalname,'dal.out.',jstepa)
      call llen(dalname,ldal)
      call llen(dalmw,ldalmw)
      call augnum(dmname,'molecule',jstepa)
      call llen(dmname,ldmol)
      info=xeq('mv '//tempdir(1:lt)//'/molecule.mol '
     &     //tempdir(1:lt)//'/'//dmname(1:ldmol)//'.mol')
      info=xeq('cp '//tempdir(1:lt)//'/molecule.dal '
     &     //tempdir(1:lt)//'/'//dmname(1:ldmol)//'.dal')

*--------------------------------------------------------------
* set maximum scratch memory if dalmw is specified in "control"
*--------------------------------------------------------------
      if(idalmw.le.800000) then
        if(idalmw.ne.0) then
          write(idbg,*) 
     & 'rslave: using dalton with default scratch memory size'
          write(idbg,*) 'idalmw = ',idalmw
         end if
*-----------
* run DALTON
*-----------
         info=xprog(nic(1:5)//progdir(1:lb)//'dalton '
     & //dmname(1:ldmol)//' '//dmname(1:ldmol),dalname(1:ldal))
      else 
         info=xprog(nic(1:5)//progdir(1:lb)//'dalton -m '
     & //dalmw(1:ldalmw)//' '//dmname(1:ldmol)//' '//dmname(1:ldmol),
     & dalname(1:ldal))
      end if
*-------------------
* get dipole moments
*-------------------
      if((calcno.ge.2.and.calcno.le.5).or.calcno.eq.8) then
        call gdaldip(dipol,tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
      else if(calcno.eq.1.or.calcno.eq.6.or.calcno.eq.7.or.
     &	      calcno.eq.666) then
        call gdaldipscf(dipol,
     &   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
      end if
      nit=0
      cpu=0
      gcpu=0
      wall=0
      gwall=0
      call mnotify(5,mypid,6,'times read',10)

*---------------------------------------------------------------------------------
* get VROA tensors as well as gradients if VROA is switched on; then, jump to the end 666 
*---------------------------------------------------------------------------------
      if (vroaflag) then
        if(calcno.eq.1.or.calcno.eq.6.or.calcno.eq.666) then
          call gdalgradscf(natoms,escf,grad,
     *     tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
           call gdalvroascf(polar,gtenlao,gtenao,aten,
     *     tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
        else
          call errex('calcno value not possible for VROA!')
        end if
        goto 666
      end if
*** if VROA is switched off proceed as usual:
*-------------------------------------
* read gradient (and polarizabilities)
*-------------------------------------
      if(calcno.ge.2.and.calcno.le.5) then
        call gdalgrad(natoms,escf,grad,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
        if(ipol.gt.0)
     *   call gdalpol(polar,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
      else if(calcno.eq.1.or.calcno.eq.6.or.calcno.eq.666) then
        call gdalgradscf(natoms,escf,grad,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
        if(ipol.gt.0)
     *   call gdalpolscf(polar,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
      else if(calcno.eq.7) then
        call gdalgradscf(natoms,escf,grad,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
        if (ipol.GT.0)
     *   call gdalpoltdhf(polar,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
      else if(calcno.eq.8) then
        call gdalgrad(natoms,escf,grad,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
        call augnum(dmname,tempdir(1:lt)//'/molecule.out.A.',jstepa)
        call llen(dmname,ldmol)
        irc=xeq('mv '//tempdir(1:lt)//'/molecule.out '//dmname(1:ldmol))

*------------------------------------------------
* special treatment in case of SOPPA calculations
*------------------------------------------------
        if (ipol.gt.0) then
          info=xeq('mv '//tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out '
     &     //tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out.A')
          info=xeq('cp '//tempdir(1:lt)//'/molecule.dal.B '
     &     //tempdir(1:lt)//'/'//dmname(1:ldmol)//'.dal ')
          if(idalmw.le.800000) then
            if(idalmw.ne.0) then
             write(idbg,*) 
     &    'rslave: using dalton with default scratch memory size'
             write(idbg,*) 'idalmw = ',idalmw
            end if
            call flush(idbg)
            info=xprog(nic(1:5)//progdir(1:lb)//'dalton '
     &       //dmname(1:ldmol)//' '//dmname(1:ldmol),dalname(1:ldal))
          else 
            info=xprog(nic(1:5)//progdir(1:lb)//'dalton -m '
     &       //dalmw(1:ldalmw)//' '//dmname(1:ldmol)//' '
     &       //dmname(1:ldmol),dalname(1:ldal))
          end if
          info=xeq('mv '//tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out ' 
     &     //tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out.B')
          call gdalpoltdhf(polar,
     *      tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out.B')
        end if
      end if

666   continue

      call mnotify(5,mypid,5,'results read',12)

      gsum=0.0d0
      do j=1,nvar    
         gsum=gsum+grad(j)**2
      enddo
      write (iosl,*) 'grad norm',gsum
      call flush(iosl)

      call clean(sdum)

*-------------------
* send final results
*-------------------
C:      call MPI_SSEND(nit,1,MPI_INTEGER,tid0,fsys_restag,w,info)
C:      call mpierr('MPI_SSEND nit','rslave',info)
C:      call MPI_SSEND(cpu,1,MPI_DOUBLE_PRECISION,tid0,801,w,info)
C:      call mpierr('MPI_SSEND cpu','rslave',info)
C:      call MPI_SSEND(wall,1,MPI_DOUBLE_PRECISION,tid0,802,w,info)
C:      call mpierr('MPI_SSEND wall','rslave',info)
C:      call MPI_SSEND(gcpu,1,MPI_DOUBLE_PRECISION,tid0,803,w,info)
C:      call mpierr('MPI_SSEND gcpu','rslave',info)
C:      call MPI_SSEND(gwall,1,MPI_DOUBLE_PRECISION,tid0,804,w,info)
C:      call mpierr('MPI_SSEND gwall','rslave',info)
C:      call MPI_SSEND(escf,1,MPI_DOUBLE_PRECISION,tid0,805,w,info)
C:      call mpierr('MPI_SSEND out1','rslave',info)
C:      call MPI_SSEND(dipol,3,MPI_DOUBLE_PRECISION,tid0,806,w,info)
C:      call mpierr('MPI_SSEND dipol','rslave',info)
C:      call MPI_SSEND(grad,nvar,MPI_DOUBLE_PRECISION,
C:   *   tid0,807,w,info)
C:      call mpierr('MPI_SSEND escf','rslave',info)
C:      IF (ipol.GT.0.and..not.vroaflag) THEN
C:       call MPI_SSEND(polar,8*ipol,MPI_DOUBLE_PRECISION,
C:   *    tid0,808,w,info)
C:       call mpierr('MPI_SSEND polar','rslave',info)
C:      end if
C:      IF (vroaflag) THEN
C:       call MPI_SSEND(polar,8*ipoldum,MPI_DOUBLE_PRECISION,
C:   *    tid0,808,w,info)
C:       call mpierr('MPI_SSEND polar','rslave',info)
C:       call MPI_SSEND(gtenlao,9*ipoldum,MPI_DOUBLE_PRECISION,
C:   *    tid0,808,w,info)
C:       call mpierr('MPI_SSEND gtenlao','rslave',info)
C:       call MPI_SSEND(gtenao,9*ipoldum,MPI_DOUBLE_PRECISION,
C:   *    tid0,808,w,info)
C:       call mpierr('MPI_SSEND gtenao','rslave',info)
C:       call MPI_SSEND(aten,27*ipoldum,MPI_DOUBLE_PRECISION,
C:   *    tid0,808,w,info)
C:       call mpierr('MPI_SSEND aten','rslave',info)
C:      end if
C//SKIPC:
C#      call MPI_SEND(nit,1,MPI_INTEGER,tid0,fsys_restag,w,info)
C#      call mpierr('MPI_SEND nit','rslave',info)
C#      call MPI_SEND(cpu,1,MPI_DOUBLE_PRECISION,tid0,801,w,info)
C#      call mpierr('MPI_SEND cpu','rslave',info)
C#      call MPI_SEND(wall,1,MPI_DOUBLE_PRECISION,tid0,802,w,info)
C#      call mpierr('MPI_SEND wall','rslave',info)
C#      call MPI_SEND(gcpu,1,MPI_DOUBLE_PRECISION,tid0,803,w,info)
C#      call mpierr('MPI_SEND gcpu','rslave',info)
C#      call MPI_SEND(gwall,1,MPI_DOUBLE_PRECISION,tid0,804,w,info)
C#      call mpierr('MPI_SEND gwall','rslave',info)
C#      call MPI_SEND(escf,1,MPI_DOUBLE_PRECISION,tid0,805,w,info)
C#      call mpierr('MPI_SEND escf','rslave',info)
C#      call MPI_SEND(dipol,3,MPI_DOUBLE_PRECISION,tid0,806,w,info)
C#      call mpierr('MPI_SEND dipol','rslave',info)
C#      call MPI_SEND(grad,nvar,MPI_DOUBLE_PRECISION,
C#   *   tid0,807,w,info)
C#      call mpierr('MPI_SEND grad','rslave',info)
C#      if (ipol.GT.0.and..not.vroaflag) then
C#       call MPI_SEND(polar,8*ipol,MPI_DOUBLE_PRECISION,
C#   *    tid0,808,w,info)
C#       call mpierr('MPI_SEND polar','rslave',info)
C#      end if
C#      if (vroaflag) then
C#       call MPI_SEND(polar,8*ipoldum,MPI_DOUBLE_PRECISION,
C#   *    tid0,808,w,info)
C#       call mpierr('MPI_SEND polar','rslave',info)
C#       call MPI_SEND(gtenlao,9*ipoldum,MPI_DOUBLE_PRECISION,
C#   *    tid0,808,w,info)
C#       call mpierr('MPI_SEND gtenlao','rslave',info)
C#       call MPI_SEND(gtenao,9*ipoldum,MPI_DOUBLE_PRECISION,
C#   *    tid0,808,w,info)
C#       call mpierr('MPI_SEND gtenao','rslave',info)
C#       call MPI_SEND(aten,27*ipoldum,MPI_DOUBLE_PRECISION,
C#   *    tid0,808,w,info)
C#       call mpierr('MPI_SEND aten','rslave',info)
C#      end if
C//END
C//SKIPC#
      call PVMFINITSEND(PVMDATADEFAULT,MBUF)
      call PVMFPACK(INTEGER4,nit,kstep,1,info)
      call PVMFPACK(REAL8,cpu,kstep,1,info)
      call PVMFPACK(REAL8,wall,kstep,1,info)
      call PVMFPACK(REAL8,gcpu,kstep,1,info)
      call PVMFPACK(REAL8,gwall,kstep,1,info)
      call PVMFPACK(REAL8,escf,1,1, INFO )
      call PVMFPACK(REAL8,dipol,3,1,INFO )
      call PVMFPACK(REAL8,grad,nvar,1,INFO )
      IF (ipol.GT.0.and..not.vroaflag) 
     *  call PVMFPACK(REAL8,polar,8*ipol,1,INFO )
      if (vroaflag) then
        call PVMFPACK(REAL8,polar,8*ipoldum,1,INFO )
        call PVMFPACK(REAL8,gtenlao,9*ipoldum,1,INFO )
        call PVMFPACK(REAL8,gtenao,9*ipoldum,1,INFO )
        call PVMFPACK(REAL8,aten,27*ipoldum,1,INFO )
      end if
      call PVMFSEND( TID0, 0, INFO )
C//END
      call mnotify(5,mypid,9,'results sent',12)
      return
      end

==> snf-4.0.0_webrelease.tar.gz: snf-4.0.0_webrelease/src/snfdc/daltonrslave.r <==
CC******************************************************************************
C   Copyright 1999 -- 2002 C. Kind, M. Reiher, J. Neugebauer, and B. A. Hess,
C   Chair of Theoretical Chemistry, Friedrich-Alexander-University 
C   Erlangen-Nuremberg, Egerlandstr. 3, D-91058 Erlangen, Germany.
C
C
C   This file is part of the package SNF.
C
C   SNF is free software; you can redistribute it and/or modify
C   it under the terms of the GNU General Public License as published by
C   the Free Software Foundation; either version 2 of the License, or
C   (at your option) any later version.
C
C   This program is distributed in the hope that it will be useful,
C   but WITHOUT ANY WARRANTY; without even the implied warranty of
C   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
C   GNU General Public License for more details.
C
C   You should have received a copy of the GNU General Public License
C   along with this program; if not, write to the Free Software
C   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
C
CC******************************************************************************
      subroutine daltonrslave(grad,co,ilab,nmode,freq,intonly,nummodes)

c     ==================================================================
c     purpose: perform a DALTON single point calculation for a displaced
c              structure, collect the results, and send them to master
c 
c     history:
c       - written by J. Neugebauer, Uni Erlangen, 2003
c       - extended by M. Reiher, Uni Erlangen, June 2003
c       - modified by M. Reiher, Uni Bonn, April 2004
c       - modified by C. Herrmann, 02/2005
c       - cleaned and modified by J. Neugebauer, ETH Zurich, 2007
c     ==================================================================

      include 'defs.h'
      include 'param.h'  

      integer ibuf,info,nn,iat,idum,ixyz,irc,idir,l
      integer idmy,j,diraus,ldal,iclean,icleanl
      character*255 dalname
      real*8 escf
      real*8 nmode(maxmode,maxatoms*3),freq(maxmode)

      integer xprogb,xprog,ldmol
      integer*4 itst,jstepa
      character*255 b1
      character*5 nic
      character*80 dalmw
      character*24 dmname
      real*8 cpu,wall,gcpu,gwall
      integer*4 nit
      integer xeq,tmpxeq,idalmw,ldalmw
      real*8 grad(nvar),dipol(3),co(3,natoms),polar(8,mxomeg)
      real*8 gtenlao(9,mxomeg),gtenao(9,mxomeg),aten(27,mxomeg)
      integer ilab(natoms)
      integer intonly,nummodes
      logical found,vroaflag


      vroaflag=.false.
      if ((ipol-1000).ge.0) vroaflag=.true.

      idalmw=0
      call clean(dalmw)

*-------------------
* call rslave module
*-------------------
      call rslave(co,ilab,jstepa,nmode,freq,intonly,nummodes,nic)

*--------------------------
* prepare output file names
*--------------------------
      call augnum(dalname,'dal.out.',jstepa)
      call llen(dalname,ldal)
      call llen(dalmw,ldalmw)
      call augnum(dmname,'molecule',jstepa)
      call llen(dmname,ldmol)
      info=xeq('mv '//tempdir(1:lt)//'/molecule.mol '
     &     //tempdir(1:lt)//'/'//dmname(1:ldmol)//'.mol')
      info=xeq('cp '//tempdir(1:lt)//'/molecule.dal '
     &     //tempdir(1:lt)//'/'//dmname(1:ldmol)//'.dal')
      if(para) then
        info=xeq('cp '//tempdir(1:lt)//'/'//dmname(1:ldmol)//'.mol '
     &     //tempdir(1:lt)//'/MOLECULE.INP')
        info=xeq('cp '//tempdir(1:lt)//'/'//dmname(1:ldmol)//'.dal '
     &     //tempdir(1:lt)//'/DALTON.INP')
      end if

      if(.not.para) then
*--------------------------------------------------------------
* set maximum scratch memory if dalmw is specified in "control"
*--------------------------------------------------------------
        if(idalmw.le.800000) then
          if(idalmw.ne.0) then
            write(idbg,*) 
     &   'rslave: using dalton with default scratch memory size'
            write(idbg,*) 'idalmw = ',idalmw
           end if
*-----------
* run DALTON
*-----------
           info=xprog(nic(1:5)//progdir(1:lb)//'dalton '
     &   //dmname(1:ldmol)//' '//dmname(1:ldmol),dalname(1:ldal))
        else 
           info=xprog(nic(1:5)//progdir(1:lb)//'dalton -m '
     &   //dalmw(1:ldalmw)//' '//dmname(1:ldmol)//' '//dmname(1:ldmol),
     &   dalname(1:ldal))
        end if
      else
        info=xprog(nic(1:5)//progdir(1:lb)//'mpiexec -conf '
     & //tempdir(1:lt)//'/dalpar.config ',dalname(1:ldal)) 
      end if
*-------------------
* get dipole moments
*-------------------
      if((calcno.ge.2.and.calcno.le.5).or.calcno.eq.8) then
        call gdaldip(dipol,tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
      else if(calcno.eq.1.or.calcno.eq.6.or.calcno.eq.7.or.
     &      calcno.eq.9) then
        call gdaldipscf(dipol,
     &   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
      end if
      nit=0
      cpu=0
      gcpu=0
      wall=0
      gwall=0
      call mnotify(5,mytid,6,'times read',10)

*---------------------------------------------------------------------------------
* get VROA tensors as well as gradients if VROA is switched on; then, jump to the end 666 
*---------------------------------------------------------------------------------
      if (vroaflag) then
        if(calcno.eq.1.or.calcno.eq.6.or.calcno.eq.9) then
          call gdalgradscf(natoms,escf,grad,
     *     tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
           call gdalvroascf(polar,gtenlao,gtenao,aten,
     *     tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
        else
          call errex('calcno value not possible for VROA!')
        end if
        goto 666
      end if
*** if VROA is switched off proceed as usual:
*-------------------------------------
* read gradient (and polarizabilities)
*-------------------------------------
      if(calcno.ge.2.and.calcno.le.5) then
        call gdalgrad(natoms,escf,grad,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
        if(ipol.gt.0)
     *   call gdalpol(polar,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
      else if(calcno.eq.1.or.calcno.eq.6.or.calcno.eq.9) then
        call gdalgradscf(natoms,escf,grad,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
        if(ipol.gt.0)
     *   call gdalpolscf(polar,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
      else if(calcno.eq.7) then
        call gdalgradscf(natoms,escf,grad,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
        if (ipol.GT.0)
     *   call gdalpoltdhf(polar,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
      else if(calcno.eq.8) then
        call gdalgrad(natoms,escf,grad,
     *   tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out')
        call augnum(dmname,tempdir(1:lt)//'/molecule.out.A.',jstepa)
        call llen(dmname,ldmol)
        irc=xeq('mv '//tempdir(1:lt)//'/molecule.out '//dmname(1:ldmol))

*------------------------------------------------
* special treatment in case of SOPPA calculations
*------------------------------------------------
        if (ipol.gt.0) then
          info=xeq('mv '//tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out '
     &     //tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out.A')
          info=xeq('cp '//tempdir(1:lt)//'/molecule.dal.B '
     &     //tempdir(1:lt)//'/'//dmname(1:ldmol)//'.dal ')
          if(idalmw.le.800000) then
            if(idalmw.ne.0) then
             write(idbg,*) 
     &    'rslave: using dalton with default scratch memory size'
             write(idbg,*) 'idalmw = ',idalmw
            end if
            call flush(idbg)
            info=xprog(nic(1:5)//progdir(1:lb)//'dalton '
     &       //dmname(1:ldmol)//' '//dmname(1:ldmol),dalname(1:ldal))
          else 
            info=xprog(nic(1:5)//progdir(1:lb)//'dalton -m '
     &       //dalmw(1:ldalmw)//' '//dmname(1:ldmol)//' '
     &       //dmname(1:ldmol),dalname(1:ldal))
          end if
          info=xeq('mv '//tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out ' 
     &     //tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out.B')
          call gdalpoltdhf(polar,
     *      tempdir(1:lt)//'/'//dmname(1:ldmol)//'.out.B')
        end if
      end if

666   continue

      call mnotify(5,mytid,5,'results read',12)

c     ------------------
c     send final results
c     ------------------
      call sendres(nit,cpu,wall,gcpu,gwall,escf,dipol,grad,
     *   polar,gtenlao,gtenao,aten,jstepa,nummodes,intonly)

      return
      end
